NumAssignRef

Trait NumAssignRef 

pub trait NumAssignRef: NumAssign + for<'r> NumAssignOps<&'r Self> { }
The trait for NumAssign types which also implement assignment operations taking the second operand by reference.

This is automatically implemented for types which implement the operators.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> NumAssignRef for T
where T: NumAssign + for<'r> NumAssignOps<&'r T>,