Struct ErrorRef
pub struct ErrorRef<'a, E>(pub &'a E)
where
E: Error + ?Sized;Expand description
A wrapper struct for serializing errors references.
This struct can be used to wrap types that don’t implement slog::Value but
do implement std::error::Error so that they can be logged.
This is usually not used directly but using #error in the macros.
This struct is available if either std or core::error::Error is.
Use ErrorValue if you want to move ownership of the error value.
Tuple Fields
0: &'a ETrait Implementations