ErrorValue

Struct ErrorValue 

pub struct ErrorValue<E>(pub E)
where
    E: Error;
A wrapper struct for serializing errors

This struct can be used to wrap types that don’t implement slog::Value but do implement std::error::Error so that they can be logged. This is usually not used directly but using #error in the macros.

This struct is only available in std because the Error trait is not available without std.

Use ErrorRef if you have an error reference.

Tuple Fields

0: E