Struct Serde
pub struct Serde<T>(pub T)
where
T: Serialize + Clone + Send + 'static;Expand description
Use to wrap a value that implements serde::Serialize so it’s written to the log record as an object, rather than a primitive.
Examples
#[derive(Clone, Serialize)]
struct Thing {
one: String,
two: String,
}
let thing = get_thing();
info!(log, "Got a thing"; "thing" => slog::Serde(thing.clone()));Tuple Fields
0: TTrait Implementations
Sourceimpl<T> SerdeValue for Serde<T>
Available on crate feature nested-values only.
impl<T> SerdeValue for Serde<T>
Available on crate feature
nested-values only.Sourcefn as_serde(&self) -> &dyn Serialize
fn as_serde(&self) -> &dyn Serialize
Convert to
erased_serde::Serialize of the underlying value,
so slog::Serializers can use it to serialize via serde.Sourcefn to_sendable(&self) -> Box<dyn SerdeValue + Send>
fn to_sendable(&self) -> Box<dyn SerdeValue + Send>
Convert to a boxed value that can be sent across threads Read more
Sourcefn serialize_fallback(
&self,
_key: &'static str,
_serializer: &mut dyn Serializer,
) -> Result<(), Error>
fn serialize_fallback( &self, _key: &'static str, _serializer: &mut dyn Serializer, ) -> Result<(), Error>
Serialize the value in a way that is compatible with
slog::Serializers
that do not support serde. Read moreSourceimpl<T> Serialize for Serde<T>
Available on crate feature nested-values only.
impl<T> Serialize for Serde<T>
Available on crate feature
nested-values only.Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more