Struct PushFnValue
pub struct PushFnValue<F>(pub F)
where
F: 'static + for<'c, 'd> Fn(&'c Record<'d>, PushFnValueSerializer<'c>) -> Result<(), Error>;Expand description
Lazy Value that writes to Serializer
It’s more ergonomic for closures used as lazy values to return type
implementing Serialize, but sometimes that forces an allocation (eg.
Strings)
In some cases it might make sense for another closure form to be used - one taking a serializer as an argument, which avoids lifetimes / allocation issues.
Generally this method should be used if it avoids a big allocation of
Serialize-implementing type in performance-critical logging statement.
use slog::{PushFnValue, Logger, Discard};
// Create a logger with a key-value printing
// `file:line` string value for every logging statement.
// `Discard` `Drain` used for brevity.
let root = Logger::root(Discard, slog::o!(
"source_location" => PushFnValue(|record , s| {
s.serialize(
format_args!(
"{}:{}",
record.file(),
record.line(),
)
)
})
));Tuple Fields
0: FTrait Implementations
Sourceimpl<F> Value for PushFnValue<F>
impl<F> Value for PushFnValue<F>